# ServiceForwarderStatus

The status properties of a ServiceForwarder. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**connection_uri** | **str** | The connection uri used to connect to the application service.  | [optional] 
**application_service** | [**ApplicationService**](ApplicationService.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


